==> LPE_1.18.0.zip: LPE/doc/LPE.R <==
###################################################
### chunk number 1:  eval=FALSE
###################################################
## packageDescription("LPE")


###################################################
### chunk number 2: 
###################################################
set.seed(0) 


###################################################
### chunk number 3: 
###################################################
library(LPE) 


###################################################
### chunk number 4: 
###################################################
data(Ley)
dim(Ley)
head(Ley)
Ley.subset <- Ley[seq(1000),]


###################################################
### chunk number 5: 
###################################################
Ley.normalized <- Ley.subset
Ley.normalized[,2:7] <- preprocess(Ley.subset[,2:7], data.type = "MAS5")
Ley.normalized[1:3,]


###################################################
### chunk number 6: 
###################################################
Ley.final <- Ley.normalized[substring(Ley.normalized$ID,1,4) !="AFFX",] 
dim(Ley.final)
Ley.final[1:3,]


###################################################
### chunk number 7: 
###################################################
var.Naive <- baseOlig.error(Ley.final[,2:4],q=0.01)
dim(var.Naive)
var.Naive[1:3,]


###################################################
### chunk number 8: 
###################################################
var.Activated <- baseOlig.error(Ley.final[,5:7], q=0.01)
dim(var.Activated)
var.Activated[1:3,]


###################################################
### chunk number 9: 
###################################################
lpe.val <- data.frame(lpe(Ley.final[,5:7], Ley.final[,2:4], 
                          var.Activated, var.Naive,
                          probe.set.name=Ley.final$ID)
                      )

lpe.val <- round(lpe.val, digits=2)
dim (lpe.val)
lpe.val[1:3,]


###################################################
### chunk number 10: 
###################################################
fdr.BH <- fdr.adjust(lpe.val, adjp="BH")
dim(fdr.BH)
round(fdr.BH[1:4, ],2)


###################################################
### chunk number 11: 
###################################################
fdr.resamp <- fdr.adjust(lpe.val, adjp="resamp", iterations=2)
fdr.resamp


###################################################
### chunk number 12: 
###################################################
Bonferroni.adjp <- fdr.adjust(lpe.val, adjp="Bonferroni")
head(Bonferroni.adjp)

==> LPE_1.24.0.zip: LPE/doc/LPE.R <==
###################################################
### chunk number 1:  eval=FALSE
###################################################
## #line 109 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
## packageDescription("LPE")


###################################################
### chunk number 2: 
###################################################
#line 119 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
set.seed(0) 


###################################################
### chunk number 3: 
###################################################
#line 124 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
library(LPE) 


###################################################
### chunk number 4: 
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
data(Ley)
dim(Ley)
head(Ley)
Ley.subset <- Ley[seq(1000),]


###################################################
### chunk number 5: 
###################################################
#line 156 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
Ley.normalized <- Ley.subset
Ley.normalized[,2:7] <- preprocess(Ley.subset[,2:7], data.type = "MAS5")
Ley.normalized[1:3,]


###################################################
### chunk number 6: 
###################################################
#line 164 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
Ley.final <- Ley.normalized[substring(Ley.normalized$ID,1,4) !="AFFX",] 
dim(Ley.final)
Ley.final[1:3,]


###################################################
### chunk number 7: 
###################################################
#line 176 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
var.Naive <- baseOlig.error(Ley.final[,2:4],q=0.01)
dim(var.Naive)
var.Naive[1:3,]


###################################################
### chunk number 8: 
###################################################
#line 185 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
var.Activated <- baseOlig.error(Ley.final[,5:7], q=0.01)
dim(var.Activated)
var.Activated[1:3,]


###################################################
### chunk number 9: 
###################################################
#line 199 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
lpe.val <- data.frame(lpe(Ley.final[,5:7], Ley.final[,2:4], 
                          var.Activated, var.Naive,
                          probe.set.name=Ley.final$ID)
                      )

lpe.val <- round(lpe.val, digits=2)
dim (lpe.val)
lpe.val[1:3,]


###################################################
### chunk number 10: 
###################################################
#line 220 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
fdr.BH <- fdr.adjust(lpe.val, adjp="BH")
dim(fdr.BH)
round(fdr.BH[1:4, ],2)


###################################################
### chunk number 11: 
###################################################
#line 232 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
fdr.resamp <- fdr.adjust(lpe.val, adjp="resamp", iterations=2)
fdr.resamp


###################################################
### chunk number 12: 
###################################################
#line 250 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmpf9E2YX/R.INSTALL57261db0/LPE/inst/doc/LPE.Rnw"
Bonferroni.adjp <- fdr.adjust(lpe.val, adjp="Bonferroni")
head(Bonferroni.adjp)
